==> haskell-typed-process-0.2.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.1.0
id: typed-process-0.2.1.0-BFlHk9HpLglLm2zRV7aBw9
key: typed-process-0.2.1.0-BFlHk9HpLglLm2zRV7aBw9
license: MIT
maintainer: michael@snoyman.com
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    System.Process.Typed
hidden-modules: Paths_typed_process
abi: c82ee4b00383699648601c2c2f6e3522
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/typed-process-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/typed-process-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/typed-process-0.2.1.0
hs-libraries: HStyped-process-0.2.1.0-BFlHk9HpLglLm2zRV7aBw9
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    bytestring-0.10.8.2 process-1.6.1.0
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x transformers-0.5.2.0
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.1.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: typed-process
version: 0.2.1.0
id: typed-process-0.2.1.0-7nskCxZ8mwDE93Ugm5Kfpk
key: typed-process-0.2.1.0-7nskCxZ8mwDE93Ugm5Kfpk
license: MIT
maintainer: michael@snoyman.com
homepage: https://haskell-lang.org/library/typed-process
synopsis: Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>
category: System
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    System.Process.Typed
hidden-modules: Paths_typed_process
abi: c69646ac91eb6eea95818ca46f93e3c0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/typed-process-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/typed-process-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/typed-process-0.2.1.0
hs-libraries: HStyped-process-0.2.1.0-7nskCxZ8mwDE93Ugm5Kfpk
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    bytestring-0.10.8.2 process-1.6.1.0
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x transformers-0.5.2.0
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-typed-process/html/typed-process.haddock
haddock-html: /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
